package org.colinvella.fancyfish.tileentity.model;

import net.minecraft.client.model.ModelBase;
import net.minecraft.client.model.ModelRenderer;
import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.entity.Entity;
import net.minecraft.util.MathHelper;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

@SideOnly(Side.CLIENT)
public class CapturedFishModel extends ModelBase
{
    public CapturedFishModel()
    {
	    textureWidth = 16;
	    textureHeight = 16;
	    
	    body = new ModelRenderer(this, 0, 0);
	    body.addBox(-0.5F, -1.5F, -2.5f, 1, 3, 5);
	    body.setRotationPoint(0F, 0F, 0F);
	    body.setTextureSize(textureWidth, textureHeight);
	    body.mirror = true;
	    setRotation(body, 0F, 0F, 0F);
	    
	    dorsalFin = new ModelRenderer(this, 0, 1);
	    dorsalFin.addBox(0F, -1F, -1F, 0, 1, 2);
	    dorsalFin.setRotationPoint(0F, -1.5F, 0F);
	    dorsalFin.setTextureSize(16, 16);
	    dorsalFin.mirror = true;
	    setRotation(dorsalFin, 0F, 0F, 0F);
	    
	    leftFin = new ModelRenderer(this, 0, 0);
	    leftFin.addBox(0F, 0F, -0.5F, 0, 1, 1);
	    leftFin.setRotationPoint(0.5F, 1.5F, 0F);
	    leftFin.setTextureSize(textureWidth, textureHeight);
	    leftFin.mirror = true;
	    setRotation(leftFin, 0F, 0F, 0F);
	    
	    rightFin = new ModelRenderer(this, 0, 0);
	    rightFin.addBox(0F, 0F, -0.5F, 0, 1, 1);
	    rightFin.setRotationPoint(-0.5F, 1.5F, 0F);
	    rightFin.setTextureSize(textureWidth, textureHeight);
	    rightFin.mirror = true;
	    setRotation(rightFin, 0F, 0F, 0F);
	    
	    tail = new ModelRenderer(this, 0, 8);
	    tail.addBox(0F, -1F, 0F, 0, 2, 3);
	    tail.setRotationPoint(0F, 0F, 2.5F);
	    tail.setTextureSize(textureWidth, textureHeight);
	    tail.mirror = true;
	    setRotation(tail, 0F, 0F, 0F);		
	}

    /**
     * Sets the models various rotation angles then renders the model.
     */
    public void render(Entity entity, float time, float limbSwingDistance, float unknown, float headYRotation, float headXRotation, float yTranslation)
    {
        this.setRotationAngles(time, limbSwingDistance, unknown, headYRotation, headXRotation, yTranslation, entity);
        
	    body.render(yTranslation);
	    dorsalFin.render(yTranslation);
	    leftFin.render(yTranslation);
	    rightFin.render(yTranslation);
	    
	    // tail animation
	    double animTime = System.currentTimeMillis() * 0.001;
		GlStateManager.pushMatrix();
		GlStateManager.rotate(15f * (float)Math.sin(animTime * Math.PI * 2), 0f, 1f, 0f);
	    tail.render(yTranslation);
	    GlStateManager.popMatrix();
    }

    /**
     * Sets the model's various rotation angles. For bipeds, par1 and par2 are used for animating the movement of arms
     * and legs, where par1 represents the time(so that arms and legs swing back and forth) and par2 represents how
     * "far" arms and legs can swing at most.
     */
    public void setRotationAngles(float time, float limbSwingDistance, float unknown, float headYRotation, float headXRotation, float yTranslation, Entity entity)
    {
        //float f6 = (MathHelper.sin(time * 0.02F) * 0.1F + 1.25F) * headYRotation;
        //this.fish.rotateAngleY = f6;
        //this.fish.rotationPointX = MathHelper.sin(f6);
    }
    
	private void setRotation(ModelRenderer model, float rotateAngleX, float rotateAngleY, float rotateAngleZ)
	{
		model.rotateAngleX = rotateAngleX;
	    model.rotateAngleY = rotateAngleY;
	    model.rotateAngleZ = rotateAngleZ;
    }
    
	// model components
	private ModelRenderer body;
	private ModelRenderer dorsalFin;
	private ModelRenderer leftFin;
	private ModelRenderer rightFin;
	private ModelRenderer tail;
	
	private static final float degToRad =  (float)Math.PI / 180.0f;
}